@@ -4,20 +4,21 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * This test is actually testing the [[Delete]] internal method (8.12.8). Since the
- * language provides no way to directly exercise [[Delete]], the tests are placed here.
+ * PutValue operates only on references (see step 1).
  *
- * @path ch11/11.4/11.4.1/11.4.1-4.a-14.js
- * @description delete operator returns true when deleting Array elements
+ * @path ch11/11.13/11.13.1/11.13.1-1-4.js
+ * @description simple assignment throws ReferenceError if LeftHandSide is not a reference (null)
  */
 
 
 function testcase() {
-
-  var a = [1,2,3]
-  a.x = 10;
-  var d = delete a[1]
-  if(d === true && a[1] === undefined)
-    return true;
+  try {
+    eval("null = 42");
+  }
+  catch (e) {
+    if (e instanceof ReferenceError) {
+      return true;
+    }
+  }
  }
 runTestCase(testcase);
